@@ -1,6 +1,6 @@
 from django.contrib import admin
 
-from .models import Role
+from .models import PermafrostRole, PermafrostCategory
 
 # ################
 # # ADMIN ACTIONS
@@ -33,23 +33,26 @@ from .models import Role
 # MODEL ADMINS
 ###############
 
-class RoleAdmin(admin.ModelAdmin):
-    # readonly_fields = ('slug',)
-    # list_display = ('name', 'category')
-    # ordering = ('name',)
+class PermafrostRoleAdmin(admin.ModelAdmin):
+    readonly_fields = ('slug',)
+    list_display = ('name', 'category')
+    ordering = ('name',)
     readonly_fields=('group','slug')
 
+    def get_readonly_fields(self, request, obj=None):
+        if obj: # editing an existing object
+            return self.readonly_fields + ('category',)
+        return self.readonly_fields
 
-# class RolePermissionAdmin(admin.ModelAdmin):
-#     # readonly_fields = ('slug',)
-#     # list_display = ('name', 'category')
-#     # ordering = ('name',)
-#     pass
-
+class PermafrostCategoryAdmin(admin.ModelAdmin):
+    readonly_fields = ('slug',)
+    list_display = ('name',)
+    ordering = ('name',)
+    readonly_fields=('slug',)
 
 ###############
 # REGISTRATION
 ###############
 
-admin.site.register(Role, RoleAdmin)
-# admin.site.register(RolePermission, RolePermissionAdmin)
+admin.site.register(PermafrostRole, PermafrostRoleAdmin)
+admin.site.register(PermafrostCategory, PermafrostCategoryAdmin)
